@@ -178,14 +178,12 @@ sub _search_packages {
 	    if (!$options{fuzzy}) {
 		if ($pack eq $v) {
 		    $exact{$v} = $id;
-		    next;
 		} elsif ($pack_a eq $v) {
 		    push @{$exact_a{$v}}, $id;
-		    next;
 		} elsif ($pack_ra eq $v || $options{src} && $pack_name eq $v) {
 		    push @{$exact_ra{$v}}, $id;
-		    next;
 		}
+		next;
 	    }
 	    if ($pack =~ /$qv/) {
 		next if member($pack, @found);
@@ -403,9 +401,9 @@ sub _resolve_priority_upgrades {
     my %priority_requested = map { $_->id => undef } @$priority_pkgs;
 
     $urpm->resolve_requested($db, \%priority_state, \%priority_requested, %options);
-    if (grep { ! exists $priority_state{selected}{$_} } keys %priority_requested) {
+    if (any { ! exists $priority_state{selected}{$_} } keys %priority_requested) {
 	#- some packages which were selected previously have not been selected, strange!
-    } elsif (grep { ! exists $priority_state{selected}{$_} } keys %$selected) {
+    } elsif (any { ! exists $priority_state{selected}{$_} } keys %$selected) {
 	#- there are other packages to install after this priority transaction.
 	%$state = %priority_state;
 	$need_restart = 1;
@@ -572,7 +570,7 @@ sub _prohibit_packages_that_would_be_removed {
     });
 
     grep {
-	! grep { $base{$_} } rejected_unsatisfied($state, $_);
+	! any { $base{$_} } rejected_unsatisfied($state, $_);
     } intersection(\@to_remove, \@base_fn);
 }
 
@@ -720,7 +718,7 @@ sub translate_why_removed_one {
 }
 
 sub _libdb_version { $_[0] =~ /libdb-(\S+)\.so/ ? version->new("v$1") : () }
-sub _rpm_version() { `rpm --version` =~ /version ([0-9.]+)$/ ? version->new("v$1") : () }
+sub _rpm_version() { `rpm --version` =~ /version ([0-9.]+)(?:-beta.*)?$/ ? version->new("v$1") : () }
 
 sub should_we_migrate_back_rpmdb_db_version {
     my ($urpm, $state) = @_;
